@@ -7,8 +7,9 @@ class CliDecodeError(CliArrError):
 
 
 class CliServerError(CliArrError):
-    def __init__(self, message: str, status_code: int):
+    def __init__(self, message: str, status_code: int, response: str):
         self.status_code = status_code
+        self.response = response
         super().__init__(message)
 
 
