@@ -66,20 +66,18 @@ class RadarrCli(BaseCliMediaApi):
         * get_system_status
         * get_queue
         * delete_queue
+        * get_history
+        * get_logs
+        * get_wanted
+        * get_blocklist
+        * delete_blocklist
     """
 
-    # Start using V3 api for implemented commands
-    api_url_base = "/api/v3"
-
     # Set api specific to radarr (differs from the default ones in BaseCliMediaApi)
-    api_url_item = f"{api_url_base}/movie"
-    api_url_itemlookup = "/api/movie/lookup"
+    api_url_item = f"{BaseCliMediaApi.api_url_base}/movie"
+    api_url_itemlookup = "f{BaseCliMediaApi.api_url_base}/movie/lookup"
 
-    # Keep using v1 for commands not available
-    api_url_profile = f"{api_url_base}/qualityProfile"
-    api_url_rootfolder = "/api/rootfolder"
-    api_url_log = "/api/log"
-    api_url_systembackup = "/api/system/backup"
+    # Keep using v1 for commands not available in v3
     api_url_wanted_missing = "/api/wanted/missing"
 
     def get_movie(self, movie_id: Optional[int] = None) -> Union[RadarrMovieItem, List[RadarrMovieItem]]:
@@ -112,18 +110,13 @@ class RadarrCli(BaseCliMediaApi):
             json response
         """
         if tmdb_id:
-            url_path = f"{self.api_url_itemlookup}/tmdb"
-            url_params: Dict[str, Any] = {"tmdbId": tmdb_id}
-            res = self.request_get(url_path, url_params=url_params)
+            term = "tmdb:" + str(tmdb_id)
         elif imdb_id:
-            url_path = f"{self.api_url_itemlookup}/imdb"
-            url_params = {"imdbId": imdb_id}
-            res = self.request_get(url_path, url_params=url_params)
-        elif term:
-            res = self.lookup_item(str(term))
-        else:
+            term = "imdb:" + str(imdb_id)
+        elif not term:
             raise RadarrCliError("Error, invalid parameters")
 
+        res = self.lookup_item(str(term))
         if not res:
             return None
         elif isinstance(res, list):
@@ -141,6 +134,7 @@ class RadarrCli(BaseCliMediaApi):
         movie_info: Optional[RadarrMovieItem] = None,
         monitored: bool = True,
         search: bool = True,
+        path: Optional[str] = None,
     ) -> json_data:
         """addMovie adds a new movie to collection.
 
@@ -149,11 +143,13 @@ class RadarrCli(BaseCliMediaApi):
 
         Args:
             quality: Quality profile to use, as retrieved by get_quality_profiles()
-            imdb_id (Optional[int]): IMDB id of the movie to add
+            imdbp_id (Optional[int]): IMDB id of the movie to add
             tmdb_id (Optional[int]): TMDB id of the movie to add
             movie_info (Optional[RadarrMovieItem]): Description of the movie to add
             monitored (bool): Whether to monitor the movie. Default is True
             search (bool): Whether to search for the movie once added. Default is True
+            path (Optional[str]): Specify the path awhere the movie should be stored.
+                Default is root/<movie name> (<movie year>).
         Returns:
             json response
         """
@@ -165,8 +161,7 @@ class RadarrCli(BaseCliMediaApi):
             raise RadarrCliError("Error, invalid parameters or invalid tmdb/imdb id")
 
         # Prepare movie info for adding
-        root_path = self.get_root_folder()
-        movie_info.path = root_path["path"] + movie_info.title
+        movie_info.path = path or self.build_movie_path(movie_info)
         movie_info.profileId = quality
         movie_info.qualityProfileId = quality
         movie_info.monitored = monitored
@@ -174,6 +169,17 @@ class RadarrCli(BaseCliMediaApi):
 
         return self.add_item(json_data=movie_info.to_dict())
 
+    def build_movie_path(self, movie_info: RadarrMovieItem, root_folder_id: int = 0) -> str:
+        """Build a movie folder path using the root folder specified.
+        Args:
+            serie_info (SonarrSerieItem) Item for which to build the path
+            root_folder_id (int): Id of the root folder (can be retrieved with get_root_folder())
+            If the id is not found or not specified, the first root folder in the list is used.
+
+        Returns: Full path of the serie in the format <root path>/<movie name> (<movie year>)
+        """
+        return self.build_item_path(movie_info.title + (f" ({movie_info.year})" if movie_info.year else ""))
+
     def delete_movie(self, movie_id: int, delete_files: bool = True, add_exclusion: bool = False) -> json_data:
         """Delete the movie with the given ID
 
@@ -184,7 +190,7 @@ class RadarrCli(BaseCliMediaApi):
         Returns:
             json response
         """
-        options = {"addExclusion": add_exclusion} if add_exclusion else {}
+        options = {"addImportExclusion": add_exclusion} if add_exclusion else {}
         return self.delete_item(movie_id, delete_files, options)
 
     def refresh_movie(self, movie_id: Optional[int] = None) -> json_data:
