@@ -80,10 +80,13 @@ class SonarrCli(BaseCliMediaApi):
     """
 
     # Set api specific to radarr (differs from the default ones in BaseCliMediaApi)
-    api_url_item = "/api/series"
-    api_url_itemlookup = "/api/series/lookup"
-    api_url_episode = "/api/episode"
-    api_url_episodefile = "/api/episodefile"
+    api_url_item = f"{BaseCliMediaApi.api_url_base}/series"
+    api_url_itemlookup = f"{BaseCliMediaApi.api_url_base}series/lookup"
+    api_url_episode = f"{BaseCliMediaApi.api_url_base}/episode"
+    api_url_episodefile = f"{BaseCliMediaApi.api_url_base}/episodefile"
+
+    # Keep using v1 for commands not available in v3
+    api_url_wanted_missing = "/api/wanted/missing"
 
     def get_serie(self, serie_id: Optional[int] = None) -> Union[SonarrSerieItem, List[SonarrSerieItem]]:
         """Get specified serie, or all if no id provided from server collection.
@@ -137,6 +140,7 @@ class SonarrCli(BaseCliMediaApi):
         monitored: bool = True,
         search: bool = True,
         season_folder: bool = True,
+        path: Optional[str] = None,
     ) -> json_data:
         """addMovie adds a new serie to collection.
 
@@ -151,6 +155,8 @@ class SonarrCli(BaseCliMediaApi):
             monitored (bool): Whether to monitor the serie. Default is True
             search (bool): Whether to search for the serie once added. Default is True
             season_folder (bool): If True (default), create a folder for each season.
+            path (Optional[str]): Specify the path awhere the movie should be stored. Default is root/<serie name>.
+
         Returns:
             json response
 
@@ -167,8 +173,7 @@ class SonarrCli(BaseCliMediaApi):
             raise SonarrCliError("Error, invalid parameters or invalid tvdb id")
 
         # Prepare serie info for adding
-        root_path = self.get_root_folder()
-        serie_info.path = root_path["path"] + serie_info.title
+        serie_info.path = path or self.build_serie_path(serie_info)
         serie_info.profileId = quality
         serie_info.qualityProfileId = quality
         serie_info.monitored = monitored
@@ -188,6 +193,17 @@ class SonarrCli(BaseCliMediaApi):
 
         return self.add_item(json_data=serie_info.to_dict())
 
+    def build_serie_path(self, serie_info: SonarrSerieItem, root_folder_id: int = 0) -> str:
+        """Build a serie folder path using the root folder specified.
+        Args:
+            serie_info (SonarrSerieItem) Item for which to build the path
+            root_folder_id (int): Id of the root folder (can be retrieved with get_root_folder())
+                If the id is not found or not specified, the first root folder in the list is used.
+
+        Returns: Full path of the serie in the format <root path>/<serie name>
+        """
+        return self.build_item_path(serie_info.title)
+
     def delete_serie(self, serie_id: int, delete_files: bool = True, add_exclusion: bool = False) -> json_data:
         """Delete the serie with the given ID
 
@@ -198,7 +214,7 @@ class SonarrCli(BaseCliMediaApi):
         Returns:
             json response
         """
-        options = {"addExclusion": add_exclusion} if add_exclusion else {}
+        options = {"addImportExclusion": add_exclusion} if add_exclusion else {}
         return self.delete_item(serie_id, delete_files, options)
 
     def refresh_serie(self, serie_id: Optional[int] = None) -> json_data:
