@@ -2,7 +2,7 @@ import datetime
 import json
 from argparse import ArgumentParser, Namespace, _SubParsersAction
 from pprint import pformat
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional, Union, no_type_check
 
 from pycliarr.api import base_api, base_media, radarr, sonarr
 
@@ -109,7 +109,7 @@ class CliSystemStatusCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.get_system_status()
-        print(f"System status: {pformat(res)}\n")
+        print(f"{pformat(res)}\n")
 
 
 class CliGetDiskSpaceCommand(CliCommand):
@@ -119,7 +119,7 @@ class CliGetDiskSpaceCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.get_disk_space()
-        print(f"Disk space: {pformat(res)}\n")
+        print(f"{pformat(res)}\n")
 
 
 class CliGetQueueCommand(CliCommand):
@@ -129,7 +129,7 @@ class CliGetQueueCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.get_queue()
-        print(f"Queue: {pformat(res)}\n")
+        print(f"{pformat(res)}\n")
 
 
 class CliGetCalendarCommand(CliCommand):
@@ -147,11 +147,11 @@ class CliGetCalendarCommand(CliCommand):
         start_date = datetime.datetime.strptime(args.start, "%Y-%m-%d") if args.start else None
         end_date = datetime.datetime.strptime(args.end, "%Y-%m-%d") if args.end else None
         res = cli.get_calendar(start_date=start_date, end_date=end_date)
-        print(f"Calendar events: {res}\n")
+        print(f"{pformat(res)}\n")
 
 
 class CliDeleteQueueCommand(CliCommand):
-    name = "delqueue"
+    name = "delete-queue"
     description = "Get list of quality profiles"
 
     def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
@@ -162,7 +162,7 @@ class CliDeleteQueueCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.delete_queue(args.id)
-        print(f"Result: {res}\n")
+        print(f"{pformat(res)}\n")
 
 
 class CliWantedCommand(CliCommand):
@@ -180,7 +180,7 @@ class CliWantedCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.get_wanted(page=args.page, sort_key=args.sort_key, page_size=args.page_size, sort_dir=args.sort_dir)
-        print(f"Result:\n{res}")
+        print(f"{pformat(res)}\n")
 
 
 class CliStatusCommand(CliCommand):
@@ -195,12 +195,218 @@ class CliStatusCommand(CliCommand):
     def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.get_command(args.id)
-        print(f"Result: {json.dumps(res)}\n")
+        print(f"{pformat(res)}\n")
+
+
+class CliGetBlocklistCommand(CliCommand):
+    name = "blocklist"
+    description = "Get blocklisted items"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--page", help="Page to get", type=int, default=1)
+        cmd_parser.add_argument("--sort-key", help="Sort key", default="date")
+        cmd_parser.add_argument("--page-size", help="Page size", type=int, default=20)
+        cmd_parser.add_argument("--sort-dir", help="Sort direction", default="descending")
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.get_blocklist(
+            page=args.page, sort_key=args.sort_key, page_size=args.page_size, sort_dir=args.sort_dir
+        )
+        print(f"{pformat(res)}\n")
+
+
+class CliDeleteBlocklistCommand(CliCommand):
+    name = "delete-blocklist"
+    description = "Get list of quality profiles"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.delete_blocklist(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliGetNotificationCommand(CliCommand):
+    name = "notification"
+    description = "Get notification(s)"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.get_notification(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliDeleteNotificationCommand(CliCommand):
+    name = "delete-notification"
+    description = "Delete the specified notification or all"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, required=True)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.delete_notification(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliPutNotificationCommand(CliCommand):
+    name = "put-notification"
+    description = "Create the specified notification"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, required=True)
+        group = cmd_parser.add_mutually_exclusive_group(required=True)
+        group.add_argument("--json", "-j", help="json data", default=None)
+        group.add_argument("--file", "-f", help="json file path", default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+
+        # Use json data from argument by default, but load json file if specified
+        if args.file:
+            with open(args.file, "r") as f:
+                notification_data = json.load(f)
+        else:
+            notification_data = json.loads(args.json)
+
+        res = cli.put_notification(args.id, notification_data)
+        print(f"{pformat(res)}\n")
+
+
+class CliGetTagCommand(CliCommand):
+    name = "tag"
+    description = "Get tag(s)"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.get_tag(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliGetTagDetailCommand(CliCommand):
+    name = "tag-detail"
+    description = "Get tag(s) details"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.get_tag_detail(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliDeleteTagCommand(CliCommand):
+    name = "delete-tag"
+    description = "Delete the specified tag"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, required=True)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.delete_tag(args.id)
+        print(f"{pformat(res)}\n")
+
+
+class CliEditTagCommand(CliCommand):
+    name = "edit-tag"
+    description = "Edit the specified tag"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="item ID", type=int, required=True)
+        cmd_parser.add_argument("--label", "-l", help="tag label", type=str, required=True)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.edit_tag(args.id, args.label)
+        print(f"{pformat(res)}\n")
+
+
+class CliGetTagItemsCommand(CliCommand):
+    name = "tag-items"
+    description = "List items with specifed tag"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        group = cmd_parser.add_mutually_exclusive_group(required=True)
+        group.add_argument("--id", "-i", help="tag id", type=int, default=None)
+        group.add_argument("--label", "-l", help="tag label", type=str, default=None)
+        return cmd_parser
+
+    @no_type_check
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = None
+        if args.label:
+            tags = cli.get_tag_detail()
+            for tag in tags:
+                if tag["label"] == args.label:
+                    res = tag
+        else:
+            res = cli.get_tag_detail(args.id)
+
+        if res:
+            print(f"Items with tag \"{res['label']}\" ({res['id']}):")
+            if "seriesIds" in res:
+                for tag_item in res["seriesIds"]:
+                    item = cli.get_serie(tag_item)
+                    print(f"    {item.title} ({item.year})")
+            elif "movieIds" in res:
+                for tag_item in res["movieIds"]:
+                    item = cli.get_movie(tag_item)
+                    print(f"    {item.title} ({item.year})")
+        else:
+            print("no such tag")
+
+
+class CliCreateTagCommand(CliCommand):
+    name = "create-tag"
+    description = "Edit the specified tag"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("label")
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.create_tag(args.label)
+        print(f"{pformat(res)}\n")
 
 
 ##############################################
 ########## radarr specific commands ##########
 ##############################################
+
+
 class CliGetMovieCommand(CliCommand):
     name = "get"
     description = "Get info on a of movie"
@@ -278,6 +484,7 @@ class CliAddMovieCommand(CliCommand):
             "--terms", "-t", help="Keyword to search for the movie to add", type=str, default=None
         )
         cmd_parser.add_argument("--quality", "-q", help="Quality profile to use", type=int, default=None)
+        cmd_parser.add_argument("--path", help="Full path where the serie should be stored", type=str, default=None)
         return cmd_parser
 
     def run(self, cli: radarr.RadarrCli, args: Namespace) -> None:
@@ -292,7 +499,13 @@ class CliAddMovieCommand(CliCommand):
         if not args.quality:
             args.quality = select_profile(cli)
 
-        res = cli.add_movie(quality=args.quality, tmdb_id=args.tmdb, imdb_id=args.imdb, movie_info=movie_info)  # type: ignore
+        res = cli.add_movie(
+            quality=args.quality,
+            tmdb_id=args.tmdb,
+            imdb_id=args.imdb,
+            movie_info=movie_info,  # type: ignore
+            path=args.path,
+        )
         print(f"Result:\n{res}")
 
 
@@ -383,6 +596,7 @@ class CliAddSerieCommand(CliCommand):
             default=False,
             action="store_true",
         )
+        cmd_parser.add_argument("--path", help="Full path where the serie should be stored", type=str, default=None)
         return cmd_parser
 
     def run(self, cli: sonarr.SonarrCli, args: Namespace) -> None:
@@ -410,6 +624,7 @@ class CliAddSerieCommand(CliCommand):
             serie_info=serie_info,  # type: ignore
             monitored_seasons=seasons,
             season_folder=args.season_folders,
+            path=args.path,
         )
         print(f"Result:\n{res}")
 
@@ -485,6 +700,17 @@ CLI_LIST: List[CliApiCommand] = [
             CliDeleteQueueCommand(),
             CliWantedCommand(),
             CliStatusCommand(),
+            CliGetBlocklistCommand(),
+            CliDeleteBlocklistCommand(),
+            CliGetNotificationCommand(),
+            CliDeleteNotificationCommand(),
+            CliPutNotificationCommand(),
+            CliGetTagCommand(),
+            CliGetTagDetailCommand(),
+            CliDeleteTagCommand(),
+            CliEditTagCommand(),
+            CliCreateTagCommand(),
+            CliGetTagItemsCommand(),
         ],
     ),
     CliApiCommand(
@@ -504,6 +730,17 @@ CLI_LIST: List[CliApiCommand] = [
             CliDeleteQueueCommand(),
             CliWantedCommand(),
             CliStatusCommand(),
+            CliGetBlocklistCommand(),
+            CliDeleteBlocklistCommand(),
+            CliGetNotificationCommand(),
+            CliDeleteNotificationCommand(),
+            CliPutNotificationCommand(),
+            CliGetTagCommand(),
+            CliGetTagDetailCommand(),
+            CliDeleteTagCommand(),
+            CliEditTagCommand(),
+            CliCreateTagCommand(),
+            CliGetTagItemsCommand(),
         ],
     ),
 ]
